@@ -5,7 +5,7 @@ class command(Decorator):
 
     # Public
 
-    marker = '_clyde_command'
+    marker = '_clyde_command_command'
 
     def __call__(self, function):
         setattr(function, self.marker, True)
