@@ -5,7 +5,7 @@ class mixin(Decorator):
 
     # Public
 
-    decorator = '_clyde_mixin'
+    decorator = '_clyde_mixin_mixin'
 
     def __init__(self, require=None):
         self.__require = require
